@@ -9,11 +9,8 @@
 
 fixed FixedMul(fixed a, fixed b)
 {
-	__int64 x = a;
-	__int64 y = b;
-	__int64 z = x * y + 0x8000;
-	
-	return (z >> 16) & 0xffffffff;
+	__int64 scratch1 = (__int64) a * (__int64) b + (__int64) 0x8000;
+	return (scratch1 >> 16) & 0xffffffff;
 }
 
 fixed FixedMulShift(fixed a, fixed b, fixed shift)
@@ -27,8 +24,8 @@ fixed FixedMulShift(fixed a, fixed b, fixed shift)
 
 fixed FixedDiv2(fixed a, fixed b)
 {
-	__int64 x = (signed long)a;
-	__int64 y = (signed long)b;
+	__int64 x = (signed int)a;
+	__int64 y = (signed int)b;
 	__int64 z = x * 65536 / y;
 	
 	return (z) & 0xffffffff;
